@@ -1190,8 +1190,17 @@ pango_font_description_to_css (PangoFontDescription *desc,
           g_string_append (s, "font-variant: normal; ");
           break;
         case PANGO_VARIANT_SMALL_CAPS:
+#if PANGO_VERSION_CHECK(1,49,3)
+        case PANGO_VARIANT_ALL_SMALL_CAPS:
+        case PANGO_VARIANT_PETITE_CAPS:
+        case PANGO_VARIANT_ALL_PETITE_CAPS:
+#endif
           g_string_append (s, "font-variant: small-caps; ");
           break;
+#if PANGO_VERSION_CHECK(1,49,3)
+        case PANGO_VARIANT_UNICASE:
+        case PANGO_VARIANT_TITLE_CAPS:
+#endif
         default:
           break;
         }
