@@ -524,6 +524,68 @@ test_axis_aligned (void)
   gsk_transform_unref (transform);
 }
 
+static void
+test_to_affine (void)
+{
+  GskTransform *transform;
+  float sx, sy, dx, dy;
+
+  transform = gsk_transform_scale (NULL, 10.0, 5.0);
+  gsk_transform_to_affine (transform, &sx, &sy, &dx, &dy);
+  gsk_transform_unref (transform);
+
+  g_assert_cmpfloat (sx, ==, 10.0);
+  g_assert_cmpfloat (sy, ==, 5.0);
+  g_assert_cmpfloat (dx, ==, 0.0);
+  g_assert_cmpfloat (dy, ==, 0.0);
+
+  transform = gsk_transform_translate (NULL, &GRAPHENE_POINT_INIT (10.0, 5.0));
+  gsk_transform_to_affine (transform, &sx, &sy, &dx, &dy);
+  gsk_transform_unref (transform);
+
+  g_assert_cmpfloat (sx, ==, 1.0);
+  g_assert_cmpfloat (sy, ==, 1.0);
+  g_assert_cmpfloat (dx, ==, 10.0);
+  g_assert_cmpfloat (dy, ==, 5.0);
+
+  transform = gsk_transform_translate (gsk_transform_scale (NULL, 2.0, 3.0), &GRAPHENE_POINT_INIT (10.0, 5.0));
+  gsk_transform_to_affine (transform, &sx, &sy, &dx, &dy);
+  gsk_transform_unref (transform);
+
+  g_assert_cmpfloat (sx, ==, 2.0);
+  g_assert_cmpfloat (sy, ==, 3.0);
+  g_assert_cmpfloat (dx, ==, 2.0 * 10.0);
+  g_assert_cmpfloat (dy, ==, 3.0 * 5.0);
+
+  transform = gsk_transform_scale (gsk_transform_translate (NULL, &GRAPHENE_POINT_INIT (10.0, 5.0)), 2.0, 3.0);
+  gsk_transform_to_affine (transform, &sx, &sy, &dx, &dy);
+  gsk_transform_unref (transform);
+
+  g_assert_cmpfloat (sx, ==, 2.0);
+  g_assert_cmpfloat (sy, ==, 3.0);
+  g_assert_cmpfloat (dx, ==, 10.0);
+  g_assert_cmpfloat (dy, ==, 5.0);
+}
+
+static void
+test_transform_bounds (void)
+{
+  GskTransform *t = gsk_transform_translate (NULL, &GRAPHENE_POINT_INIT (50, 50));
+  graphene_rect_t bounds = GRAPHENE_RECT_INIT (0, 0, 100, 100);
+  graphene_rect_t out;
+
+  gsk_transform_transform_bounds (t, &bounds, &out);
+  g_assert_true (graphene_rect_equal (&out, &GRAPHENE_RECT_INIT(50, 50, 100, 100)));
+
+  t = gsk_transform_rotate (t, 180);
+  gsk_transform_transform_bounds (t, &bounds, &out);
+  g_assert_true (graphene_rect_equal (&out, &GRAPHENE_RECT_INIT(-50, -50, 100, 100)));
+
+  t = gsk_transform_translate (t, &GRAPHENE_POINT_INIT (-50, -50));
+  gsk_transform_transform_bounds (t, &bounds, &out);
+  g_assert_true (graphene_rect_equal (&out, &GRAPHENE_RECT_INIT(0, 0, 100, 100)));
+}
+
 int
 main (int   argc,
       char *argv[])
@@ -537,6 +599,8 @@ main (int   argc,
   g_test_add_func ("/transform/invert", test_invert);
   g_test_add_func ("/transform/print-parse", test_print_parse);
   g_test_add_func ("/transform/check-axis-aligneness", test_axis_aligned);
+  g_test_add_func ("/transform/to-affine", test_to_affine);
+  g_test_add_func ("/transform/bounds", test_transform_bounds);
 
   return g_test_run ();
 }
